@@ -1,8 +1,10 @@
-from .send_message import send_message
-from .edit_message_text import edit_message_text
-from .set_my_commands import set_my_commands
-from .send_video import send_video
 from .answer_callback_query import answer_callback_query
+from .edit_message_text import edit_message_text
 from .get_file import get_file, get_file_url
-from .send_chat_action import send_chat_action
 from .get_me import get_me
+from .send_chat_action import send_chat_action
+from .send_message import send_message
+from .send_photo import send_photo
+from .send_video import send_video
+from .set_my_commands import set_my_commands
+from .send_media_group import send_media_group
